@@ -10,6 +10,11 @@ TARGET=`readlink -f $1`
 DEB_TARGET_GNU_CPU=$2
 DEB_TARGET_GNU_SYSTEM=$3
 
+if [ x"$TARGET" = x ]; then
+  echo "Refused to overwrite inexistent/empty TARGET."
+  exit 1
+fi
+
 . /usr/share/crosshurd/functions
 
 debs=`cat /etc/crosshurd/packages/{common,$DEB_TARGET_GNU_SYSTEM} | grep -v '^#'`
@@ -36,8 +41,10 @@ extract `(cd $TARGET/var/cache/apt/archives && \
 	for i in *.deb; do dpkg-deb --field $i Priority | grep ^required \
 	&& echo $i; done) | cut -d _ -f 1`
 
-if [ -e $TARGET/var/cache/apt/archives/gnumach-image-1.6-486_* ] ; then
-        extract gnumach-image-1.6-486
+if [ -e $TARGET/var/cache/apt/archives/gnumach-image-1.7-486_* ] ; then
+        extract gnumach-image-1.7-486
+	# place symlink for compatibility with update-grub (/etc/grub.d/30_os-prober)
+	ln -s gnumach-1.7-486.gz "$TARGET/boot/gnumach.gz"
 fi
 
 if [ -e $TARGET/var/cache/apt/archives/libbz2-1.0_* ] ; then
